library ControlPL;

//  Name : CONTROLPL
//  Description : Sample Windows control panel applet.
//  Author : Neil Jones (abton@operamail.com)
//  Date : 10/03/1999
//
//  Notes :
//
//  I created this as I could not find an example Control Panel applet
//  written in Delphi anywhere.  You are free to use it as you wish.
//
//  A control panel applet is basically a DLL that displays a modal form
//  renamed with a '.cpl' extension.
//  But, it must export a function called CPlApplet that processes a series
//  of messages sent by Windows in a specific order.
//  To install the applet, just place it in your \windows\system directory.
//
//  Please note, Windows caches the icon, title and description information.
//  So if you change them and they do not change in the control panel - delete
//  the '.cpl' from the \windows\system directory and copy in a new one.

uses
  SysUtils,
  CPL,         //  Include this for the message definitions etc.
  Dialogs,
  Windows,
  Classes;

//  Include required resources (an icon and two strings)
//  See main.rc for more details
{$R main.res}

var
   CPLInfo : pCPLINFO;
   ThisInst, IconHandle : integer;

//  The exported function MUST be declared like this!
function CPlApplet(hwndCPl: THandle; uMsg: DWORD;
                   lParam1, lParam2: Longint): Longint; stdcall;
begin
     //  You MUST process these events
     case uMsg of
          //  CPL_INIT - Initialise the application.  Put your initialisation
          //  code here.
          CPL_INIT : begin
                          //  Use the name of your control panel applet here
                          ThisInst := GetModuleHandle('ControlPL.cpl');
                          //  Get a handle to our icon from main.res for use later
                          IconHandle := LoadIcon(ThisInst, 'APPLET_ICON');
                          //  Return nonzero to indicate success
                          result := 1;
                     end;
          //  CPL_GETCOUNT - Return the number of dialogs we have (only 1 in this case)
          CPL_GETCOUNT : result := 1;
          //  CPL_INQUIRE - Return information required to display an icon in the control panel.
          CPL_INQUIRE : begin
                             //  lParam2 is a pointer to a CPLINFO structure, so get a handle to it.
                             CPLInfo := pCPLINFO(lParam2);
                             //  Point the icon towards the icon handle obtained earlier.
                             CPLInfo^.idIcon := IconHandle;
                             //  The app name is defined in string resource 1 (see main.rc)
                             CPLInfo^.idName := 1;
                             //  The app description is defined in string resource 2 (see main.rc)
                             CPLInfo^.idInfo := 2;
                             //  Not used so set to 0
                             CPLInfo^.lData := 0;
                             //  Return zero to indicate success
                             result := 0;
                        end;
          //  CPL_DBLCLK - This occurs when our app is actually run.
          CPL_DBLCLK : begin
                            //  Call your dialog/modal form from here.
                            //  Note - the form must be modal
                            ShowMessage('Control Panel Applet Launched');
                            //  Return zero to indicate success
                            result := 0;
                       end;
          //  CPL_STOP - Called when application is de-initialised
          CPL_STOP : begin
                          //  Perform your cleanup code here.
                          //  Return zero to indicate success
                          result := 0;
                     end;
          //  CPL_EXIT - Control panel is exiting.
          CPL_EXIT : begin
                          //  Return zero to indicate success
                          result := 0;
                     end;
     else
         //  All other events, just return 0 (processed OK)
         result := 0;
     end;
end;

exports
       CPlApplet;

begin
end.
